/*
 * Copyright (c) 2018, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: MIT
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/MIT
 */
import * as http from 'http';
import * as https from 'https';
import { URL } from 'node:url';
import { WebSocketServer } from 'ws';
import { LogLevel } from '../../types/index.js';
function requestHandler(req, res) {
    // the second arg could really be anything, we're just interested in searchParams
    // also req.url can never be undefined, it's just bad typing
    const url = new URL(req.url, 'http://localhost');
    const redirectUrl = url.searchParams.get('redirectUrl');
    if (redirectUrl) {
        res.statusCode = 302;
        res.setHeader('Location', redirectUrl);
        return res.end();
    }
    res.writeHead(200, { 'Content-Type': 'text/html' });
    res.end(`Visit https://&lt;salesforce-url&gt;?0.aura.mode=devpreview`);
}
export function startWebSocketServer({ port, https: httpsConfig }, logger) {
    const httpServer = httpsConfig ? https.createServer(httpsConfig) : http.createServer();
    httpServer.on('request', requestHandler);
    try {
        const wss = new WebSocketServer({ server: httpServer });
        httpServer.listen(port);
        logger.log(LogLevel.info, `[LWC Dev Server] LWC Dev Server started at port:${port}`);
        return wss;
    }
    catch (e) {
        logger.log(LogLevel.error, `[LWC Dev Server] Failed to start a WebSocket server with the following error: ${e}`);
        process.exit(1);
    }
}
//# sourceMappingURL=web-socket-server.js.map